Module: Linzer::HTTP::Bootstrap Private

Defined in:
lib/linzer/http/bootstrap.rb

Overview

This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.

Handles lazy loading of http.rb gem dependencies.

The http.rb gem integration is optional and only loaded when explicitly required via ‘require “linzer/http/signature_feature”`.

Class Method Summary collapse

Class Method Details

.load_dependenciesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Loads dependencies, raising a helpful error if http gem is missing.

Raises:

  • (Error)

    If the http gem is not installed



23
24
25
26
27
28
# File 'lib/linzer/http/bootstrap.rb', line 23

def load_dependencies
  require_dependencies
rescue LoadError
  msg = "http gem is required to be installed to use this feature."
  raise Linzer::Error, msg
end

.require_dependenciesObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Requires the http gem and related adapters.



15
16
17
18
# File 'lib/linzer/http/bootstrap.rb', line 15

def require_dependencies
  require "http"
  require_relative "../message/adapter/http_gem/request"
end