Class: Linzer::Message::Field Private
- Inherits:
-
Object
- Object
- Linzer::Message::Field
- Defined in:
- lib/linzer/message/field.rb,
lib/linzer/message/field/parser.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Handles HTTP message field identification and serialization.
Fields represent HTTP header fields and derived components that can be included in signatures. This class handles parsing and serialization of component identifiers according to RFC 9421.
Defined Under Namespace
Modules: IdentifierMethods Classes: Identifier