Module: Rack::Auth::Signature::Helpers::Key Private

Included in:
Rack::Auth::Signature::Helpers
Defined in:
lib/rack/auth/signature/helpers.rb

Overview

This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.

Resolves verification keys from the middleware configuration.

Keys can be configured inline (with :material) or via file path (with :path). When a keyid is present in the signature, the corresponding key is looked up in the :keys hash. If not found, the :default_key is used as fallback.