Module: Rack::Auth::Signature::Helpers::Parameters Private

Included in:
Rack::Auth::Signature::Helpers
Defined in:
lib/rack/auth/signature/helpers.rb

Overview

This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.

Validates the presence of required signature parameters.

Each method checks whether a specific parameter is required (per configuration) and, if so, whether it is present and valid in the current signature.