Module: Linzer::Ed25519
- Defined in:
- lib/linzer/ed25519.rb
Overview
Ed25519 elliptic curve signature algorithm support.
Ed25519 is a modern, high-security signature algorithm that is fast and produces compact signatures. It’s recommended for new applications where compatibility with older systems is not required.
Defined Under Namespace
Classes: Key