Module: Rack
- Defined in:
- lib/rack/auth/signature.rb,
lib/rack/auth/signature/helpers.rb
Overview
Rack::Auth::Signature implements HTTP Message Signatures, as per RFC 9421.
Initialize with the Rack application that you want protecting. A hash with options and a block can be passed to customize, enhance or disable security checks applied to incoming requests.
Defined Under Namespace
Modules: Auth